#
# spec file for package llvm
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _revision 262553
%define _release_version 3.8.0

%define build_lldb 0
%define build_libcxx 0
%define build_openmp 0

%ifarch x86_64
%define build_libcxx 1
%define build_lldb 1
%endif

%ifarch ppc64 ppc64le %{ix86} x86_64
%define build_openmp 1
%endif

%if !0%{?is_opensuse}
%define build_libcxx 0
%define build_lldb 0
%define build_openmp 0
%endif

Name:           llvm
Version:        3.8.0
Release:        5.1
Summary:        Low Level Virtual Machine
License:        NCSA
Group:          Development/Languages/Other
Url:            http://www.llvm.org
Source0:        http://llvm.org/releases/%{version}/llvm-%{version}.src.tar.xz
Source1:        http://llvm.org/releases/%{version}/cfe-%{version}.src.tar.xz
Source2:        http://llvm.org/releases/%{version}/compiler-rt-%{version}.src.tar.xz
Source3:        http://llvm.org/releases/%{version}/libcxx-%{version}.src.tar.xz
Source4:        http://llvm.org/releases/%{version}/libcxxabi-%{version}.src.tar.xz
Source5:        http://llvm.org/releases/%{version}/openmp-%{version}.src.tar.xz
# Manually created docs
# cd docs
# make -f Makefile.sphinx man html
# cd ..
# tar cvJf llvm-docs-3.8.0.src.tar.xz llvm-3.8.0.src/docs/_build/{man,html}
Source6:        llvm-docs-%{version}.src.tar.xz
Source7:        cfe-docs-%{version}.src.tar.xz
Source8:        http://llvm.org/releases/%{version}/clang-tools-extra-%{version}.src.tar.xz
Source9:        http://llvm.org/releases/%{version}/lldb-%{version}.src.tar.xz
Source100:      %{name}-rpmlintrc
Source101:      baselibs.conf
# PATCH-FIX-OPENSUSE set-revision.patch idoenmez@suse.de -- Allow us to set revision
Patch1:         set-revision.patch
# PATCH-FIX-OPENSUSE assume-opensuse.patch idoenmez@suse.de -- Always enable openSUSE/SUSE features
Patch2:         assume-opensuse.patch
# PATCH-FIX-OPENSUSE default-to-i586.patch -- Use i586 as default target for 32bit
Patch3:         default-to-i586.patch
# PATCH-FIX-OPENSUSE arm_suse_support.diff --Enable ARM suse toolchain support
Patch4:         arm_suse_support.diff
Patch5:         clang-resourcedirs.patch
Patch6:         llvm-remove-clang-only-flags.patch
Patch7:         llvm-fix-find-gcc5-install.patch
Patch8:         revert-cmake-soname.patch
Patch9:         lldb-cmake.patch
# PATCH-FIX-UPSTREAM llvm-fix-unavailable-functions-amdgpu.patch -- https://reviews.llvm.org/D21282
Patch10:        llvm-fix-unavailable-functions-amdgpu.patch
# PATCH-FIX-UPSTREAM llvm-aarch64-relocations.patch -- https://reviews.llvm.org/rL289880
Patch11:        llvm-aarch64-relocations.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  binutils-devel >= 2.21.90
BuildRequires:  bison
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc5
BuildRequires:  gcc5-c++
BuildRequires:  groff
BuildRequires:  libedit-devel
BuildRequires:  libstdc++-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  ninja
BuildRequires:  python-base
BuildRequires:  python-xml
# llvm does not work on ppc or s390
ExcludeArch:    ppc s390

%description
LLVM is a compiler infrastructure designed for compile-time,
link-time, runtime, and idle-time optimization of programs from
arbitrary programming languages.

The compiler infrastructure includes mirror sets of programming
tools as well as libraries with equivalent functionality.

%package -n libLLVM
Summary:        Libraries for LLVM
Group:          Development/Libraries/C and C++

%description -n libLLVM
This package contains the shared libraries needed for LLVM.

%package devel
Summary:        Header Files for LLVM
Group:          Development/Languages/Other
Requires:       %{name} = %{version}

%description devel
This package contains library and header files needed to develop
new native programs that use the LLVM infrastructure.

%package clang
Summary:        CLANG frontend for LLVM
Group:          Development/Languages/Other
Provides:       clang

%description clang
This package contains the clang (C language) frontend for LLVM.

%package -n libclang
Summary:        Library files needed for clang
Group:          Development/Libraries/C and C++

%description -n libclang
This package contains the shared libraries needed for clang.

%package clang-devel
Summary:        CLANG frontend for LLVM (devel package)
Group:          Development/Languages/Other
Requires:       llvm-clang = %{version}
Requires:       llvm-devel = %{version}

%description clang-devel
This package contains the clang (C language) frontend for LLVM.
(development files)

%package        vim-plugins
Summary:        Vim plugins for LLVM
Group:          Productivity/Text/Editors
Requires:       vim

%description    vim-plugins
This package contains vim plugins for LLVM like syntax highlighting.

%package -n python-clang
Summary:        Python bindings for libclang
Group:          Development/Languages/Python
Requires:       libclang = %{version}
Requires:       python

%description -n python-clang
This package contains the Python bindings to clang (C language) frontend for LLVM.

%if %{build_lldb}
%package -n     lldb
Summary:        Next generation high-performance debugger
# We don't want to provide an unstable lldb-devel package now.
# Reconsider later when it has a stable API.
Group:          Development/Languages
Provides:       lldb-devel = %{version}
Obsoletes:      lldb-devel < %{version}

%description -n lldb
LLDB is a next generation, high-performance debugger. It is built as a set
of reusable components which highly leverage existing libraries in the
larger LLVM Project, such as the Clang expression parser and LLVM
disassembler.
%endif

%prep
%setup -q -a 1 -a 2 -a 3 -a 4 -a 5 -a 7 -a 8 -a 9 -b 6 -n %{name}-%{version}.src
%patch1
%patch2
%patch3
%patch4
%patch5
%patch6 -p1
%patch7
%patch8 -p1
%patch9
%patch10 -p1
%patch11 -p1

# Move into right place
mv cfe-%{version}.src tools/clang
mv compiler-rt-%{version}.src projects/compiler-rt
mv clang-tools-extra-%{version}.src tools/clang/tools/extra

%if %{build_openmp}
mv openmp-%{version}.src  projects/openmp
%endif

%if %{build_libcxx}
mv libcxx-%{version}.src projects/libcxx
mv libcxxabi-%{version}.src projects/libcxxabi

rm projects/libcxx/test/std/localization/locale.categories/category.time/locale.time.get.byname/get_monthname.pass.cpp
rm projects/libcxx/test/std/localization/locale.categories/category.time/locale.time.get.byname/get_monthname_wide.pass.cpp
%endif

%if %{build_lldb}
mv lldb-%{version}.src tools/lldb
%endif

# We hardcode i586
rm tools/clang/test/Driver/x86_features.c
rm tools/clang/test/Driver/nacl-direct.c

sed -i s,SVN_REVISION,\"%{_revision}\",g tools/clang/lib/Basic/Version.cpp
sed -i s,LLVM_REVISION,\"%{_revision}\",g tools/clang/lib/Basic/Version.cpp

%if %{build_lldb}
sed -i s,LLDB_REVISION,\"%{_revision}\",g tools/lldb/source/lldb.cpp
%endif

# ARMv6 needs this exact host triple
%ifarch armv6hl
cat > autoconf/config.guess << EOF
#!/bin/sh
echo armv6hl-suse-linux-gnueabi
EOF
%endif

%build
TOPLEVEL=$PWD
mkdir stage1 stage2
pushd stage1

export CC=gcc-5
export CXX=g++-5

cmake -G "Ninja" \
      -DBUILD_SHARED_LIBS=ON \
      -DCMAKE_BUILD_TYPE=Release \
      -DLLVM_ENABLE_ASSERTIONS=OFF \
      -DLLVM_TARGETS_TO_BUILD=host \
      -DLLDB_DISABLE_PYTHON=ON \
%ifarch armv6hl
      -DCMAKE_C_FLAGS="-target armv6hl-suse-linux-gnueabi -mfloat-abi=hard -march=armv6zk -mtune=arm1176jzf-s -mfpu=vfp" \
      -DCMAKE_CXX_FLAGS="-target armv6hl-suse-linux-gnueabi -mfloat-abi=hard -march=armv6zk -mtune=arm1176jzf-s -mfpu=vfp" \
%endif
%ifarch armv7hl
      -DCMAKE_C_FLAGS="-mfloat-abi=hard -march=armv7-a -mtune=cortex-a9 -mfpu=vfpv3-d16" \
      -DCMAKE_CXX_FLAGS="-mfloat-abi=hard -march=armv7-a -mtune=cortex-a9 -mfpu=vfpv3-d16" \
%endif
      ..

ninja %{?_smp_mflags} clang -v

popd
pushd stage2

export CC=$TOPLEVEL/stage1/bin/clang
export CXX=$TOPLEVEL/stage1/bin/clang++

cmake -G "Ninja" \
      -DBUILD_SHARED_LIBS=ON \
%ifarch %arm ppc64 ppc64le
      -DCMAKE_BUILD_TYPE=Release \
%else
      -DCMAKE_BUILD_TYPE=RelWithDebInfo \
%endif
      -DCMAKE_INSTALL_PREFIX=%{_prefix} \
%ifarch armv6hl
      -DCMAKE_C_FLAGS="-target armv6hl-suse-linux-gnueabi -mfloat-abi=hard -march=armv6zk -mtune=arm1176jzf-s -mfpu=vfp" \
      -DCMAKE_CXX_FLAGS="-target armv6hl-suse-linux-gnueabi -mfloat-abi=hard -march=armv6zk -mtune=arm1176jzf-s -mfpu=vfp" \
      -DLLVM_DEFAULT_TARGET_TRIPLE=armv6-unknown-linux-gnueabihf \
%endif
%ifarch armv7hl
      -DCMAKE_C_FLAGS="-mfloat-abi=hard -march=armv7-a -mtune=cortex-a9 -mfpu=vfpv3-d16" \
      -DCMAKE_CXX_FLAGS="-mfloat-abi=hard -march=armv7-a -mtune=cortex-a9 -mfpu=vfpv3-d16" \
      -DLLVM_DEFAULT_TARGET_TRIPLE=armv7l-unknown-linux-gnueabihf \
%endif
%if "%{_lib}" == "lib64"
      -DLLVM_LIBDIR_SUFFIX=64 \
%endif
      -DLLVM_REQUIRES_RTTI=ON \
      -DLLVM_ENABLE_TIMESTAMPS=OFF \
      -DLLVM_ENABLE_ASSERTIONS=OFF \
      -DLLVM_ENABLE_PIC=ON \
      -DLLVM_BINUTILS_INCDIR=/usr/include \
%ifarch %{ix86} x86_64
      -DLLVM_TARGETS_TO_BUILD="all" \
%else
      -DLLVM_TARGETS_TO_BUILD=host \
%endif
%if %{build_lldb}
      -DLLDB_DISABLE_PYTHON=ON \
%endif
      ..

ninja %{?_smp_mflags} -v

%check
cd stage2
%ifnarch armv7hl armv7l
%if 0%{!?qemu_user_space_build:1}
# we just do not have enough memory with qemu emulation

ninja check
ninja clang-test

%if %{build_libcxx}

ninja check-libcxx
ninja check-libcxxabi
%endif

%endif
%endif

%install
cd stage2
DESTDIR=%{buildroot} ninja install
cd ..

# Build man/html pages
cd docs
# Docs are prebuilt due to sphinx dependency
#make -f Makefile.sphinx html man
rm -rf %{buildroot}/usr/docs

mkdir -p %{buildroot}%{_docdir}/llvm/html
mkdir -p %{buildroot}/usr/share/man/man1
cp -r _build/man/* %{buildroot}/usr/share/man/man1
cp -r _build/html/* %{buildroot}%{_docdir}/llvm/html

cd ../tools/clang/docs
mkdir -p %{buildroot}%{_docdir}/llvm-clang/html
cp -r _build/man/* %{buildroot}/usr/share/man/man1
cp -r _build/html/* %{buildroot}%{_docdir}/llvm-clang/html
cd ../../..

# install python bindings
install -d %{buildroot}%{py_sitedir}/clang
pushd tools/clang/bindings/python
cp clang/*.py %{buildroot}%{py_sitedir}/clang
install -d %{buildroot}%{_docdir}/python-clang/examples/cindex
cp -r examples %{buildroot}%{_docdir}/python-clang
install -d %{buildroot}%{_docdir}/python-clang/tests/cindex/INPUTS
cp -r tests %{buildroot}%{_docdir}/python-clang
popd

mkdir -p %{buildroot}%{_libdir}/bfd-plugins
ln -s %{_libdir}/LLVMgold.so %{buildroot}%{_libdir}/bfd-plugins/

install -m 755 -d %{buildroot}%{_datadir}/vim/site/
for i in ftdetect ftplugin indent syntax; do
    cp -r utils/vim/$i %{buildroot}%{_datadir}/vim/site/
done
mv utils/vim/README utils/vim/README.vim

mv %{buildroot}%{_prefix}/libexec/{c++,ccc}-analyzer %{buildroot}%{_bindir}
chmod -x %{buildroot}%{_mandir}/man1/scan-build.1

# Stuff we don't want to include
rm %{buildroot}%{_mandir}/man1/lit.1

%if %{build_openmp}
rm  %{buildroot}%{_libdir}/libgomp.so
rm  %{buildroot}%{_libdir}/libiomp*.so
%endif

%if %{build_lldb}
rm %{buildroot}%{_libdir}/liblldb*.a
rm %{buildroot}%{_libdir}/liblldb.so
rm -r %{buildroot}%{_includedir}/lldb
%endif

%fdupes -s %{buildroot}%{_docdir}/%{name}
%fdupes -s %{buildroot}%{_docdir}/%{name}-doc

%post -n libLLVM -p /sbin/ldconfig
%postun -n libLLVM -p /sbin/ldconfig

%post clang -p /sbin/ldconfig
%postun clang -p /sbin/ldconfig

%post -n libclang -p /sbin/ldconfig
%postun -n libclang -p /sbin/ldconfig

%post clang-devel -p /sbin/ldconfig
%postun clang-devel -p /sbin/ldconfig

%if %{build_lldb}
%post -n lldb -p /sbin/ldconfig
%postun -n lldb -p /sbin/ldconfig
%endif

%files
%defattr(-,root,root)
%{_bindir}/bugpoint
%{_bindir}/llc
%{_bindir}/lli
%exclude %{_bindir}/llvm-config
%{_bindir}/llvm*
%{_bindir}/obj2yaml
%{_bindir}/opt
%{_bindir}/sancov
%{_bindir}/verify-uselistorder
%{_bindir}/yaml2obj
%exclude %{_mandir}/man1/llvm-config.1%{ext_man}
%{_mandir}/man1/bugpoint.1%{ext_man}
%{_mandir}/man1/tblgen.1%{ext_man}
%{_mandir}/man1/llc.1%{ext_man}
%{_mandir}/man1/lli.1%{ext_man}
%{_mandir}/man1/llvm*.1%{ext_man}
%{_mandir}/man1/FileCheck.1%{ext_man}
%{_mandir}/man1/opt.1%{ext_man}

%files -n libLLVM
%defattr(-,root,root,-)
%{_libdir}/libLLVM*.so.*

%files clang
%defattr(-,root,root)
%{_bindir}/c-index-test
%{_bindir}/c++-analyzer
%{_bindir}/ccc-analyzer
%{_bindir}/clang
%{_bindir}/clang-*
%{_bindir}/clang++
%{_bindir}/clang-format
%{_bindir}/git-clang-format
%{_bindir}/modularize
%{_bindir}/scan-build
%{_bindir}/scan-view
%{_datadir}/clang
%{_datadir}/scan-build
%{_datadir}/scan-view
%{_mandir}/man1/clang.1%{ext_man}
%{_mandir}/man1/scan-build.1%{ext_man}
%{_libdir}/libLTO.*
%if %{build_openmp}
%{_libdir}/libomp.so
%endif
%if %{build_libcxx}
%{_libdir}/libc++*
%{_includedir}/c++/*
%endif
%{_libdir}/LLVMgold.so
%{_libdir}/bfd-plugins/
%{_libdir}/clang
%ifnarch s390x
%{_libdir}/clang/%{_release_version}/lib/linux/
%endif

%files -n libclang
%defattr(-,root,root,-)
%{_libdir}/libclang*.so.*

%files clang-devel
%defattr(-,root,root)
%{_libdir}/libclang*.so
%{_includedir}/clang
%{_includedir}/clang-c
%doc %{_docdir}/llvm-clang

%files devel
%defattr(-,root,root,-)
%{_bindir}/llvm-config
%{_libdir}/libLLVM*.so
%{_libdir}/BugpointPasses.*
%{_libdir}/LLVMHello.*
%doc %{_mandir}/man1/llvm-config.1%{ext_man}
%{_includedir}/llvm/
%{_includedir}/llvm-c/
%dir %{_datadir}/llvm
%{_datadir}/llvm/cmake/
%doc %{_docdir}/llvm

%files vim-plugins
%defattr(-,root,root,-)
%doc utils/vim/README.vim
%{_datadir}/vim/

%files -n python-clang
%defattr(-,root,root)
%{py_sitedir}/clang
%{py_sitedir}/clang/__init__.py
%{py_sitedir}/clang/cindex.py
%{py_sitedir}/clang/enumerations.py
%doc %{_docdir}/python-clang

%if %{build_lldb}
%files -n lldb
%defattr(-,root,root,-)
%{_libdir}/liblldb.so.*
%{_bindir}/lldb*
%endif

%changelog
* Tue Jul  4 2017 fcrozat@suse.com
- Increase disk requirement to 20G to fix build on i586.
* Wed Apr 26 2017 idonmez@suse.com
- Add llvm-aarch64-relocations.patch to fix relocations on AARCH64
  bsc#1032686
* Sat Feb  4 2017 rpm@fthiessen.de
- Added llvm-fix-unavailable-functions-amdgpu.patch,
  fixes boo#1023614
* Wed May 18 2016 idonmez@suse.com
- Disable libcxx/lldb/openmp for SLE fate#319582
* Thu Apr 21 2016 idonmez@suse.com
- Update rpmlintrc to whitelist libLTO.so fate#319582
* Mon Apr  4 2016 idonmez@suse.com
- Update llvm-remove-clang-only-flags.patch to remove
  - Wcovered-switch-default flag for gcc compatibility.
* Wed Mar 30 2016 idonmez@suse.com
- Set disk requirement to 15G to fix s390x build fate#319582
* Wed Mar  9 2016 idonmez@suse.com
- Update to llvm 3.8.0 fate#319582
  * See http://llvm.org/releases/3.8.0/docs/ReleaseNotes.html and
    http://llvm.org/releases/3.8.0/tools/clang/docs/ReleaseNotes.html
- Drop clang-disable-ada-extension.patch, libcxxabi-exceptions.patch
  and cmake-host-triple.patch
- Add revert-cmake-soname.patch to fix soname handling
* Thu Feb 11 2016 sndirsch@suse.com
- latest version required for new mesa on sle12
  (fate #315643-315645, 319159-319161, 319618)
- obsoletes patches:
  * backport-llvm*
  * backport-clang*
  * aarch64-workaround.patch
  * clang-mainline-backports.patch
  * llvm-34branch-backports.patch
  * llvm-mainline-backports.patch
- Remove FFI support because its fragile
* Thu Feb 11 2016 sndirsch@suse.com
- Enable OpenMP for x86, x86_64, ppc64 and ppc64le
* Thu Feb 11 2016 sndirsch@suse.com
- Enable all targets on x86, x86_64
* Thu Feb 11 2016 sndirsch@suse.com
- Update to version 3.7.0
  * See http://llvm.org/releases/3.7.0/docs/ReleaseNotes.html
- Merge aarch64-suse-support.patch into arm_suse_support.diff
- Refresh arm_suse_support.diff, llvm-fix-find-gcc5-install.patch
- Remove llvm-fix-parsearmarch.patch, upstream.
* Thu Feb 11 2016 sndirsch@suse.com
- fix build on s390x (one typo in ifarch and one change in filelist)
* Thu Feb 11 2016 sndirsch@suse.com
- Update to version 3.6.1
  * No changelog upstream
* Thu Feb 11 2016 sndirsch@suse.com
- Add llvm-fix-parsearmarch.patch to fix parsing armv{6,7}hl archs.
* Thu Feb 11 2016 sndirsch@suse.com
- Update to version 3.6.0
  * See http://llvm.org/releases/3.6.0/docs/ReleaseNotes.html
- Add python-xml dependency for regression tests
- Removed the following patches, fixed upstream:
  * arm-remove-xfails.diff
  * libcxx-libdir.patch
  * llvm-config-lib64.patch
  * llvm-fix-intrusiverefcntptr.patch
* Thu Feb 11 2016 sndirsch@suse.com
- Add llvm-fix-intrusiverefcntptr.patch to fix build of LLVM tools
  with GCC 5.
- Add llvm-fix-find-gcc5-install.patch to properly find installed GCC 5.
* Thu Feb 11 2016 sndirsch@suse.com
- Add a gcc dependency for clang, this is heavyweight but we need
  libgcc_s which comes with the gcc package (bnc#893359)
* Thu Feb 11 2016 sndirsch@suse.com
- Conditionalize libcxx{abi} build on build_libcxx variable
- Turn libc++.so into an ldscript so it links to libc++abi
  automatically.
* Thu Feb 11 2016 sndirsch@suse.com
- fix constraints for armv6l/armv7l (there is no 4GB RAM on 32bit)
* Thu Feb 11 2016 sndirsch@suse.com
- Rename llvm-remove-werror-date-time.patch to
  llvm-remove-clang-only-flags.patch and remove more clang only
  flags.
* Thu Feb 11 2016 sndirsch@suse.com
- Enable shared libs on PPC64
* Thu Feb 11 2016 sndirsch@suse.com
- Require llvm-clang not just clang
* Thu Feb 11 2016 sndirsch@suse.com
- Add llvm-remove-werror-date-time.patch to remove -Werror=date-time
  for CXXFLAGS, gcc does not support it and it creeps into
  llvm-config --cflags
* Thu Feb 11 2016 sndirsch@suse.com
- Remove wrong Requires from the llvm-devel package
* Thu Feb 11 2016 sndirsch@suse.com
- Add default target triple form ARM, fixes bnc#893359
* Thu Feb 11 2016 sndirsch@suse.com
- Use ninja for building
* Thu Feb 11 2016 sndirsch@suse.com
- Update to llvm 3.5.0
  * Major update, see http://llvm.org/releases/3.5.0/docs/ReleaseNotes.html
- Use upstream pristine tarballs
- Add libc++/libc++abi support clang (only on x86_64)
- Add libcxxabi-exceptions.patch to fix libcxxabi exception handling
- Add libcxx-libdir.patch to fix libdir on 64bit arches
- Remove asan-disable-hugemalloctest.patch and
  cmake-patchversion.patch, fixed upstream.
* Thu Feb 11 2016 sndirsch@suse.com
- Fix the sed line for minimal damage.
* Thu Feb 11 2016 sndirsch@suse.com
- Add baselibs.conf to source files
* Thu Feb 11 2016 sndirsch@suse.com
- Add cmake-patchversion.patch to sync config.h.in
  with config.h.cmake
* Thu Feb 11 2016 sndirsch@suse.com
- Update to llvm 3.4.2
  * Minor bugfix release
- Drop clang-max_align_t.patch, applied upstream.
* Thu Feb 11 2016 sndirsch@suse.com
- Add clang-max_align_t.patch to resolve issue with libstdc++ 4.9
  max_align_t missing declaration
* Thu Feb 11 2016 sndirsch@suse.com
- build compiler-rt on ppc64 (don't delete it)
* Thu Feb 11 2016 sndirsch@suse.com
- Fix resource dir for libclang case (clang-resourcedirs.patch)
- Always build tests
* Thu Feb 11 2016 sndirsch@suse.com
- complete ifarchs for s390
* Thu Feb 11 2016 sndirsch@suse.com
- Remove non-existing doc subpackage
* Thu Feb 11 2016 sndirsch@suse.com
- enable ppc64le
* Tue Sep 15 2015 idonmez@suse.com
- Add backport-llvm-r247694 to fix bsc#945912
* Wed Aug 19 2015 idonmez@suse.com
- Add s390 to excluded arches (complimentary to bsc#936459)
* Tue Jul 21 2015 idonmez@suse.com
- Disable make check on aarch64 as other ARM arches
- Add aarch64-workaround.patch to workaround a gcc miscompilation
- Implement fate#318027 and fate#318040 bsc#936459
- Following patches are provided by IBM:
  * backport-clang-r206364
    backport-clang-r233543
    backport-clang-r233544
    backport-clang-r233574
    backport-clang-r233804
    backport-clang-r233807
    backport-clang-r236531
    backport-clang-r236532
    backport-llvm-r195471
    backport-llvm-r196578
    backport-llvm-r196579
    backport-llvm-r196580
    backport-llvm-r196905
    backport-llvm-r196906
    backport-llvm-r197030
    backport-llvm-r197032
    backport-llvm-r197170
    backport-llvm-r197234
    backport-llvm-r197235
    backport-llvm-r197236
    backport-llvm-r197238
    backport-llvm-r197239
    backport-llvm-r197802
    backport-llvm-r197804
    backport-llvm-r197908
    backport-llvm-r197909
    backport-llvm-r197984
    backport-llvm-r197985
    backport-llvm-r197986
    backport-llvm-r198862
    backport-llvm-r199114
    backport-llvm-r199115
    backport-llvm-r199116
    backport-llvm-r199117
    backport-llvm-r203103
    backport-llvm-r203234
    backport-llvm-r204049
    backport-llvm-r204200
    backport-llvm-r204451
    backport-llvm-r204452
    backport-llvm-r205625
    backport-llvm-r205626
    backport-llvm-r210263
    backport-llvm-r212242
    backport-llvm-r212610
    backport-llvm-r212612
    backport-llvm-r212614
    backport-llvm-r212661
    backport-llvm-r212701
    backport-llvm-r212702
    backport-llvm-r212703
    backport-llvm-r212707
    backport-llvm-r212711
    backport-llvm-r212714
    backport-llvm-r215409
    backport-llvm-r216131
    backport-llvm-r218560
    backport-llvm-r219069
    backport-llvm-r220945
    backport-llvm-r221336
    backport-llvm-r229652
    backport-llvm-r229654
    backport-llvm-r229658
    backport-llvm-r233541
    backport-llvm-r233688
    backport-llvm-r233689
    backport-llvm-r233690
    backport-llvm-r233700
    backport-llvm-r233736
    backport-llvm-r233803
    backport-llvm-r236430
    backport-llvm-r236432
    backport-llvm-r236433
    backport-llvm-r236520
    backport-llvm-r236521
    backport-llvm-r236522
    backport-llvm-r236523
    backport-llvm-r236524
    backport-llvm-r236525
    backport-llvm-r236526
    backport-llvm-r236527
    backport-llvm-r236528
    backport-llvm-r236529
    backport-llvm-r236530
* Fri Aug 22 2014 idonmez@suse.com
- Fix the sed command on 64bit, this should fix the dynamic linker
  problem with clang -m32.
* Thu Aug  7 2014 idonmez@suse.com
- Update ppc64le patches (bnc#887778)
- Drop llvm-ppc64le.patch and clang-ppc64le.patch, obsoleted.
* Wed May 14 2014 idonmez@suse.com
- Update llvm-ppc64le.patch to remove XFAIL from llvm-ppc64le.patch
  (bnc#865586)
* Tue May 13 2014 idonmez@suse.com
- Initial PPC64LE port by IBM (bnc#865586)
* Mon Apr  7 2014 idonmez@suse.com
- Add clang-resourcedirs.patch to fix resource directories for
  libclang case.
- Add PPC64LE support, just the ifdefs for now.
- Remove empty -doc package.
* Thu Mar 13 2014 ro@suse.de
- extend build constraints from 4G to 6G disk-space
* Fri Jan 24 2014 idonmez@suse.com
- Add a dependency on ncurses-devel since libLLVM now links to
  tinfo.
* Tue Jan 14 2014 idonmez@suse.com
- Add 32bit libclang bnc#857131
* Tue Jan  7 2014 idonmez@suse.com
- Update to final llvm 3.4 release
  * See http://llvm.org/releases/3.4/docs/ReleaseNotes.html for
    complete changelog.
* Tue Dec 24 2013 idonmez@suse.com
- Update to final release candidate (r197980)
* Sat Dec 21 2013 idonmez@suse.com
- Update to r197866 from release_34 branch
* Tue Dec 17 2013 idonmez@suse.com
- Update to r197490 from release_34 branch
* Thu Dec 12 2013 idonmez@suse.com
- Update to r197142 from release_34 branch
- Disable assertions again now that PPC64 backend is fixed
* Tue Dec 10 2013 idonmez@suse.com
- Update to r196899 from release_34 branch
- Remove compiler_rt-r196612.patch, merged upstream
* Mon Dec  9 2013 idonmez@suse.com
- Add compiler_rt-r196612.patch to fix ubsan failures on i586
* Mon Dec  9 2013 idonmez@suse.com
- Update to r196762 from release_34 branch
* Thu Dec  5 2013 idonmez@suse.com
- Update to r196503 from release_34 branch to get compiler_rt fixes
* Thu Dec  5 2013 idonmez@suse.com
- Update to r196487 from release_34 branch to get compiler_rt fixes
* Wed Dec  4 2013 idonmez@suse.com
- Ship cmake files for llvm (needed for lldb and such)
* Wed Dec  4 2013 idonmez@suse.com
- Update to r196371 from release_34 branch
* Wed Dec  4 2013 termim@gmail.com
- install python binding to libclang
* Sun Dec  1 2013 idonmez@suse.com
- Update to r196358 from llvm 3.4 branch
- Add asan-disable-hugemalloctest.patch to disable
  ASAN HugeMallocTest, it requires 4.1+ GB of RAM.
- Refresh patches
  * aarch64-suse-support.patch
  * arm_suse_support.diff
  * assume-opensuse.patch
  * default-to-i586.patch
- Drop upstream patches
  * llvm-disable-pretty-stack-trace.patch
  * r189852.diff
  * unreachable-code.patch
  * llvm-no-visibility.patch
* Tue Oct 22 2013 dmueller@suse.com
- add r189852.diff: Remove vtables optimisation that breaks ARM
  and PowerPC
- Disable testsuite on ARMv7, takes forever to run
* Thu Oct 17 2013 schwab@suse.de
- Fix file list for %%arm
* Wed Oct  9 2013 dmueller@suse.com
- use %%arm, not arm in arch conditions
- add arm-remove-xfails.diff: remove XFAILs in testsuite
  that pass and thereby make check fail
* Fri Sep 27 2013 idonmez@suse.com
- Set DisablePrettyStackTrace to true since it messes up signal
  handling. bnc#839074 and fdo#60929 implemented with
  llvm-disable-pretty-stack-trace.patch)
* Wed Aug 28 2013 schwab@suse.de
- Fix filelist for aarch64
* Wed Aug 28 2013 schwab@suse.de
- aarch64-suse-support.patch: Enable AArch64 suse toolchain support
* Wed Aug 28 2013 idonmez@suse.com
- Add s390x support
* Wed Aug 28 2013 idonmez@suse.com
- Remove unused chrpath dependency
- Re-enable ARCMT since libclang depends on it
* Mon Aug 26 2013 schwab@suse.de
- Define host_triple for aarch64
* Thu Aug 22 2013 idonmez@suse.com
- Fix ARMv6 build
* Wed Aug 21 2013 idonmez@suse.com
- Only enable PowerPC on ppc64
* Mon Aug 12 2013 idonmez@suse.com
- Disable shared libs on PowerPC
- Disable ARCMT, it only makes sense for iOS/OSX
* Tue Aug  6 2013 idonmez@suse.com
- Fix build
* Wed Jul 17 2013 idonmez@suse.com
- Disable building unit-tests, should fix undefined reference
  problem on ARM & PowerPC
* Tue Jul 16 2013 coolo@suse.com
- do not build on slow or low memory workers
* Thu Jul  4 2013 idonmez@suse.com
- Drop disable_neon_in_armv7.diff, neon seems to be working fine
- Add cmake-host-triple.patch to pass a host triple argument
* Wed Jul  3 2013 idonmez@suse.com
- Create libLLVM and libclang subpackages.
* Wed Jun 19 2013 llunak@suse.com
- Fix finding internal headers on x86_64
* Wed Jun 19 2013 idonmez@suse.com
- Fix ARM v5/v7 builds
* Tue Jun 18 2013 tobias.johannes.klausmann@mni.thm.de
- Create a baselibs.conf
  Provide *-32 Bit Packages for x86_64
* Thu Jun 13 2013 tobias.johannes.klausmann@mni.thm.de
- Initial version of a cmake based buildscript
  + Updated arm_suse_support.diff (patch6) to work with llvm 3.3
  + Set version in spec to 3.3
* Thu Jun 13 2013 idonmez@suse.com
- Update to final 3.3 release (r183898)
* Fri May 24 2013 idonmez@suse.com
- Disable debug symbols on PPC64
* Tue May 21 2013 idonmez@suse.com
- Update to version 3.3 RC2
  * Small bugfixes
* Tue May 14 2013 idonmez@suse.com
- Enable ARM64 support
* Thu May  9 2013 idonmez@suse.com
- Add unreachable-code.patch to fix unreachable code warnings on SLE
* Wed May  8 2013 idonmez@suse.com
- Update to version 3.3 RC1
  * Added support for AArch64, ARM’s 64-bit architecture.
  * LLVM now has a new SLP vectorizer.
  * LLVM and clang now support IBM’s z/Architecture.
  * The R600 backend was added in this release, it supports
    AMD GPUs (HD2XXX - HD7XXX).
  * See http://llvm.org/releases/3.3/docs/ReleaseNotes.html for
    complete changelog.
- Drop upstream patches:
  * pr13303.patch
  * pr14795.patch
  * pr14831.patch
  * python-ulimit.patch
* Wed Jan 16 2013 llunak@suse.com
- pr13303.patch: reapply, was temporarily reverted upstream
* Fri Jan 11 2013 idonmez@suse.com
- Add pre-generated doc files, remove sphinx dependency
* Tue Jan  8 2013 llunak@suse.com
- pr14795.patch: Fix incorrect line numbers after -frewrite-includes
  (PR#14795)
- pr14831.patch: Do not incorrectly warn about pragmas in -frewrite-includes
  (PR#14831)
* Mon Dec 31 2012 dmueller@suse.com
- disable cross-compile mode in stage2 for armv5/v7
* Thu Dec 20 2012 idonmez@suse.com
- Update to final 3.2 release
  * No code changes since rc3
* Sun Dec 16 2012 idonmez@suse.com
- Update to r170281 from release_32 branch
  * SROA fixes
* Fri Dec 14 2012 idonmez@suse.com
- Disable compilation on PPC, only PPC64 is supported.
* Fri Dec 14 2012 idonmez@suse.com
- Add python-ulimit.patch: Don't set a limit on address space.
  This enables us running tests on PowerPC.
* Wed Dec 12 2012 idonmez@suse.com
- Unbreak PowerPC support
* Sat Dec  8 2012 idonmez@suse.com
- Update to r169678 from release_32 branch
  * This is 3.2rc3
* Wed Dec  5 2012 idonmez@suse.com
- Update to r169391 from release_32 branch
  * SROA fixes
* Tue Dec  4 2012 guillaume@opensuse.org
- Fix ARM build
* Mon Dec  3 2012 schuetzm@gmx.net
- Fix llvm-config --libdir to return /usr/lib64 where appropriate.
  The old method of using sed on the executable does no longer
  work, because llvm-config is now a binary.
* Fri Nov 30 2012 idonmez@suse.com
- Update to r168987 from release_32 branch
  * Crash fixes
  * Miscompilation fixes
* Tue Nov 20 2012 idonmez@suse.com
- Stop excluding ppc64 architecture
* Tue Nov 20 2012 idonmez@suse.com
- Update to r168357 from release_32 branch
  * Fixes a miscompilation with gcc 4.7
* Sun Nov 18 2012 idonmez@suse.com
- Update to r168286 from release_32 branch
  * Fixes llvm PR14309
* Thu Nov 15 2012 idonmez@suse.com
- Update to r168031 from release_32 branch
  * This is 3.2rc1
* Mon Nov 12 2012 idonmez@suse.com
- Update to r167720 from release_32 branch
  * Thread local variables may have a specified TLS model.
  * LLVM now has a loop optimizer.
  * SROA has been rewritten to be more powerful.
  * A new optimization pass added to merge stack objects
    which are used in disjoint areas of the code.
  * LLVM now merge consecutive loads and stores.
  * New TableGen infrastructure to support bundling for
    Very Long Instruction Word (VLIW) architectures.
  * Added a new target independent VLIW packetizer.
  * A probability based block placement and code layout algorithm
    was added to LLVM's code generator.
  * The ARM target now includes a full featured macro assembler,
    including direct-to-object module support for clang.
  * A new IR-level pass, called "TargetTransformInfo" provides
    a number of low-level interfaces.
- Refresh default-to-i586.patch to apply again
- Drop following patches (fixed upstream)
  * arm-suse-support.patch
  * pr12463.patch
  * pr13141.patch
  * pr13303.patch
  * rewrite-includes.patch
  * clang-fix-mips-test.patch (fixed differently in spec file)
* Sat Oct 27 2012 coolo@suse.com
- add explicit buildrequire groff for man pages
* Mon Sep 10 2012 idonmez@suse.com
- Fix debuginfo generation
* Thu Jul 19 2012 llunak@suse.com
- make link time optimization plugin accessible to ar/nm/ranlib
- build the plugin properly
* Sat Jul 14 2012 adrian@suse.de
- fix arm build
* Fri Jul 13 2012 llunak@suse.com
- change rewrite-includes patch to use options to match upstream
  changed option names
* Fri Jul 13 2012 llunak@suse.com
- fix debuginfo generation (PR#13303)
* Mon Jun 18 2012 llunak@suse.com
- Do not reject PCH because of -DFOO duplication (PR#13141)
* Tue May 15 2012 idonmez@suse.com
- Update to final 3.1 release
* Thu May 10 2012 idonmez@suse.com
- Depend on python-base so we don't pull whole Mesa
* Tue May  8 2012 llunak@suse.com
- make -rewrite-includes support -C and -CC
* Thu May  3 2012 llunak@suse.com
- patch for -rewrite-includes feature
* Mon Apr 30 2012 idonmez@suse.com
- Update to svn revision 155819 from 3.1 branch
  * C++11 fixes
* Fri Apr 27 2012 idonmez@suse.com
- Update to svn revision 155700 from 3.1 branch
  * Crash fixes
  * C++11 fixes
* Thu Apr 26 2012 idonmez@suse.com
- Update to svn revision 155574 from 3.1 branch
  * Crash fixes
  * Correctly enable compiler-rt
  * Remove unneeded runtime python dependencies
* Thu Apr 26 2012 idonmez@suse.com
- Switch to 2-stage bootstrap because we don't do build-compare
  anyway.
* Wed Apr 25 2012 idonmez@suse.com
- More fixes to llvm-config
* Tue Apr 24 2012 idonmez@suse.com
- Fix llvm-config --libs output
* Sun Apr 22 2012 idonmez@suse.com
- Update to svn revision 155320 from 3.1 branch
  * AVX fixes
* Tue Apr 17 2012 idonmez@suse.com
- Update to svn revision 154914 from 3.1 branch
  Major new features:
  * AddressSanitizer, a fast memory error detector.
  * MachineInstr Bundles, Support to model instruction
    bundling / packing.
  * ARM Integrated Assembler, A full featured assembler
    and direct-to-object support for ARM.
  * Basic Block Placement Probability driven basic block placement.
  LLVM IR and Core Improvements
  * IR support for half float
  * IR support for vectors of pointers, including vector GEPs.
  * Module flags have been introduced.
  * Loads can now have range metadata attached to them to
    describe the possible values being loaded.
  * Inline cost heuristics have been completely overhauled
    and now closely model constant propagation through call sites,
    disregard trivially dead code costs, and
    can model C++ STL iterator patterns.
  Optimizer Improvements
  * The loop unroll pass now is able to unroll loops with
    run-time trip counts. This feature is turned off by default,
    and is enabled with the -unroll-runtime flag.
  * A new basic-block autovectorization pass is available.
    Pass -vectorize to run this pass along with some associated
    post-vectorization cleanup passes.
  X86-32 and X86-64 Target Improvements
  * Bug fixes and improved support for AVX1
  * Support for AVX2 (still incomplete at this point)
  ARM Target Improvements
  * The constant island pass now supports basic block and
    constant pool entry alignments greater than 4 bytes.
  Clang Changes
  * New: -Wdangling-else, -Wstrncat-size
  * Improved: -Wformat, -Wempty-body, -Wliteral-conversion
  * Clang 3.1 adds support for anonymous structs and anonymous unions,
    added in the latest ISO C standard. Use -std=c11 or -std=gnu11
    to enable support for the new language standard.
    The new C11 features are backwards-compatible and are available
    as an extension in all language modes.
  * All warning and language selection flags which previously accepted
    c1x have been updated to accept c11. The old c1x forms have been removed.
  * Generalized constant expressions
  * Lambda expressions
  * Generalized initializers
  * Unrestricted unions
  * User-defined literals
  * Forward-declared enumerations
  * Atomics (both libc++'s and libstdc++4.7's <atomic> are supported)
* Tue Mar 20 2012 idonmez@suse.com
- Target i586-linux for 32bit builds
* Tue Dec 27 2011 idonmez@suse.com
- Add upstream fix for llvm PR11642
* Sun Dec 25 2011 idonmez@suse.com
- Don't run gcc for ada files, just fail instead.
* Thu Dec 22 2011 idonmez@suse.com
- Add clang-glibc2.14.patch to support glibc 2.14 headers
- Install profiling support
* Mon Dec  5 2011 idoenmez@suse.de
- Switch to 3-stage bootstrap
* Fri Dec  2 2011 idoenmez@suse.de
- Build first stage compiler with -O0 to workaround gcc 4.5 bug
* Thu Dec  1 2011 idoenmez@suse.de
- Update to final 3.0 release
  * No real change since rc2
* Tue Nov 29 2011 idoenmez@suse.de
- Use %%{_lib} macro instead of checking for x86_64
* Wed Nov 16 2011 idonmez@suse.com
- Enable ARM support again
- Switch to optimized build
* Thu Nov 10 2011 idonmez@suse.com
- Disable ARM support, VM goes out of memory while compiling it
* Thu Nov 10 2011 idonmez@suse.com
- Really enable ARM support
- Remove forcing -frtti
* Mon Nov  7 2011 idonmez@suse.com
- Update to r143961 from llvm-3.0 branch
  * No longer hardcoding include paths
* Mon Nov  7 2011 idonmez@suse.com
- Fix LLVMgold.so path for x86-64
* Sun Nov  6 2011 idonmez@suse.com
- Enable ld gold support
* Tue Nov  1 2011 idonmez@suse.com
- Update r143456 from llvm-3.0 branch
  * llvm/clang 3.0rc2
* Fri Oct 28 2011 idonmez@suse.com
- Add llvm-pr9614-part{1,2}.patch to fix LLVM PR9614
* Fri Oct 28 2011 idonmez@suse.com
- Fixup dependencies so that llvm-clang doesn't depend
  on llvm-clang-devel
* Tue Oct 25 2011 idonmez@suse.com
- Update to r142912 llvm-3.0 branch
  * Fixes to python bindings
* Fri Oct 21 2011 idonmez@suse.com
- Update to r142641
  * llvm/clang 3.0 rc1
* Thu Oct 20 2011 idonmez@suse.com
- Enable ARM code generation
* Wed Oct 19 2011 idonmez@suse.com
- Fix libdir on x86_64
* Tue Oct 18 2011 idonmez@suse.com
- Update to r142341
  * First build from 3.0 branch
  * -Wc++98-compat warnings for the lexer
  * Add flags for the remaining shift related warnings
    (-Wshift-count-negative, -Wshift-count-overflow).
  * Only warn in -Wliteral-conversion if the conversion
    loses information
  * Added clang_getCompletionAnnotation and
    clang_getCompletionNumAnnotations to retrieve annotations
    from completion string.
  * Add support for -std=gnu90 and -std=c++03, for compatibility
    with modern gcc.
- Switch to tar.bz2 and remove xz dependency
* Thu Sep 29 2011 idonmez@suse.com
- Update to r140780
  * Code cleanup
  * Crash fixes
  * Add support for alignment-specifiers in C1X and C++11
  * Introduce a new compiler switch: -fms-compatility
  * Emit debug info for c++0x nullptr.
* Tue Sep 13 2011 idonmez@suse.com
- Update to r139589
  * C++0x fixes
  * PCH fixes
* Thu Sep  1 2011 idonmez@suse.com
- Update to r138939
  * Many crash fixes.
  * Performance optimizations.
  * Allow C99 hexfloats in C++0x mode.
  * Add missing function _mm_ucomige_sd to emmintrin.h.
* Fri Aug 12 2011 idonmez@novell.com
- Update to r137452
  * Fix problems found by PVS-Studio
  * More AVX fixes
  * Many C++ fixes
- Add assume-opensuse.patch to remove dependency on openSUSE-release
* Wed Aug  3 2011 idonmez@novell.com
- Update to r136773
  * Many AVX fixes
  * Support for C++0x unicode string and character literals
* Tue Jul 19 2011 vljn@ovi.com
- Update to r135431
  * API changes to match Mesa requirements
* Mon Jul 11 2011 idonmez@novell.com
- Update to r134888
  * Type system rewrite
* Sat Jul  9 2011 idonmez@novell.com
- Update to r134813
  * Mainly gcc compatibility fixes
* Fri Jul  8 2011 idonmez@novell.com
- Update to r134698
  * Up to 80x speed improvements with -Wuninitialized
* Thu Jul  7 2011 idonmez@novell.com
- Enable RTTI support
- Disable assertions because they are not thread safe
- Update to r134611
  * Many C++ fixes and speedups
  * Updates for AVX instruction support
  * gcc 4.6.1 support
* Sat Jul  2 2011 idonmez@novell.com
-  Fix manpage generation (bnc #703591)
* Sun Jun  5 2011 idonmez@novell.com
- Update to r132667
* Sun May 29 2011 idonmez@novell.com
- Update to use cmake buildsystem
- Remove unmaintained ocaml support
* Thu May 26 2011 idonmez@novell.com
- Drop ocaml support because its unmaintained
- Update to latest svn revision 132050
  + Start of the upcoming 3.0 version
  + Support for gcc 4.6 c++ headers
  + Better support for C++0x
* Fri Apr 29 2011 idoenmez@novell.com
- Fix ocaml dependency
* Thu Apr  7 2011 idoenmez@novell.com
- Update to 2.9
  + Type Based Alias Analysis (TBAA) is now implemented in clang
  + LLVM now generates better debug information
  + Inline assembly now supports multiple alternative constraints
* Wed Apr  6 2011 stepan@coresystems.de
- drop revision from Requires: fields
- update to 2.8.99 revision 129008.
* Mon Mar  7 2011 jslaby@suse.de
- spec file cleanup
* Wed Dec 22 2010 dmacvicar@suse.de
- Do not require specific ffi version but gather the
  appropiate one from the distro
* Fri Dec 10 2010 reddwarf@opensuse.org
- Fix compatibility with C++0x compilers (g++ 4.5)
* Mon Nov 29 2010 ismail@namtrac.org
- Fix C include paths
* Fri Nov 26 2010 ismail@namtrac.org
- Fix header path for openSUSE 11.4
- Enabled PIC for x86 for loadable module support
- Enable package tests for llvm and clang
- Disable package timestamps to silence an rpmlint warning
* Wed Jun  2 2010 anschneider@exsuse.de
- Fixed the build on x86 plattforms.
- Package the clang c++-analyzer.
* Sat May  1 2010 jslaby@suse.de
- update to llvm 2.7
* Mon Mar 15 2010 jslaby@suse.de
- added vim plugins
* Sun Mar 14 2010 jslaby@suse.de
- added libffi-devel to llvm-devel requires so that build does not fail
- fixed build of explicit constructors with gcc45
* Mon Nov  2 2009 jslaby@suse.de
- Initial 2.6 release
